S3 function to friendly construct S4 Stratified.ceg.model.
Usage
Stratified.ceg.model(stratified.staged.tree)
Arguments
stratified.staged.tree
Stratified.staged.tree S4 object A staged tree is called stratified if
its supporting event tree is stratified and all vertices which are in the same stage
are also at the same distance of edges from the root.